(defun dotfile-insert (text)
  (if (and (mark t) mark-active)
      (let ((mark-start nil) (mark-end nil))
        (if (< (region-beginning) (region-end))
            (progn
              (setq mark-start (copy-marker (region-beginning)))
              (setq mark-end (copy-marker (region-end))))
          (progn
            (setq mark-end (copy-marker (region-beginning)))
            (setq mark-start (copy-marker (region-end)))))
            
           (goto-char mark-start)
           (insert-string "\\")
           (insert-string text)
           (insert-string "{")
           (goto-char mark-end)
           (insert-string "}")
           )
       (progn
         (insert-string "\\")
         (insert-string text)
         (insert-string "{}")
         (backward-char)
         )))

(defun dotfile-doc () 
  (interactive)
  (setq dotfile-map (make-sparse-keymap))
  (global-set-key "\C-z" dotfile-map)
  
  (define-key dotfile-map "w"
    (lambda () (interactive) (dotfile-insert "widget")))
  (define-key dotfile-map "f"
    (lambda () (interactive) (dotfile-insert "function")))
  (define-key dotfile-map "c"
    (lambda () (interactive) (dotfile-insert "command")))
  (define-key dotfile-map "s"
    (lambda () (interactive) (dotfile-insert "switch")))
  (define-key dotfile-map "v"
    (lambda () (interactive) (dotfile-insert "variable")))
  )

(defun dotfile-insert-header (text)
  (let*
      ((length (length text))
       (pre (- 34 (floor (/ length 2.0))))
       (post (- 34 (ceiling (/ length 2.0)))))
    (insert (concat (make-string pre ?#) " " text " " (make-string post ?#)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Map for inserting headers
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(setq dotfile-map (make-sparse-keymap))
(global-set-key "\C-z" dotfile-map)
  
(define-key dotfile-map "h"
  (lambda () (interactive) (dotfile-insert-header "Help")))
(define-key dotfile-map "w"
  (lambda () (interactive) (dotfile-insert-header "Widgets")))
(define-key dotfile-map "f"
  (lambda () (interactive) (dotfile-insert-header "Functions")))
(define-key dotfile-map "s"
  (lambda () (interactive) (dotfile-insert-header "Save")))
(define-key dotfile-map "c"
  (lambda () (interactive) (dotfile-insert-header "Change")))
(define-key dotfile-map "p"
  (lambda () (interactive) (dotfile-insert-header "Page End")))
(define-key dotfile-map "i"
  (lambda () (interactive) (dotfile-insert-header "Init")))


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; This  function insert the region into the buffer *DOTFILE HELP*
;;; and strips its delimiters
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun dotfile-help (start end)
  (interactive "r")
  (let ( (current-buf (current-buffer))
         (help-buf (get-buffer-create "*DOTFILE HELP*")))

    (dotfile-create-help-buffer)
    
    ;; help-buf
    (set-buffer help-buf)
    (erase-buffer)
    (insert-buffer-substring current-buf start end)
    
    ;; orig buffer
    (set-buffer current-buf)
    (delete-region start end)
    (setq dotfile-point (point))
        
    ;; help-buf
    (set-buffer help-buf)

    ;;; replace all opening quotes
    (goto-char (point-min))
    (while (re-search-forward "^[ 	]*\"" nil t)
      (replace-match "" nil nil))

    ;;; replace all closing quotes
    (goto-char (point-min))
    (while (re-search-forward "\"[ 	]*\\\\$" nil t)
      (replace-match "" nil nil))

    ;;; replace the last closing quote
    (re-search-forward "\"[ 	]*$" nil t)
    (replace-match "" nil nil)
    (fill-region (point-min) (point-max))

    ;;; goto the start of the buffer
    (goto-char (point-min))
    ))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; This function creates the *DOTFILE HELP* buffer if it doesn't
;;; exists. It also bind the key Ctrl-Q
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun dotfile-create-help-buffer ()
  (interactive)
  (let ((help-buf (get-buffer-create "*DOTFILE HELP*")))
    (setq dotfile-buffer (current-buffer))
    (setq dotfile-point (point))
    (set-buffer help-buf)
    (pop-to-buffer help-buf)
    (local-set-key "" 'dotfile-insert-back)
    (auto-fill-mode 1)
    (setq fill-column 75)
    (set-buffer dotfile-buffer)))
  
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; This function insert the content of the *DOTFILE HELP* buffer
;;; at point in the original buffer
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun dotfile-insert-back ()
  (interactive)
  (let ( (start (point-min))
         (end "")
         (length 0)
         (help-buf (get-buffer "*DOTFILE HELP*")))

    ;; original buffer
    (set-buffer dotfile-buffer)
    (goto-char dotfile-point)
    
    ;;; help buffer
    (set-buffer help-buf)
    (goto-char (point-min))
    (while (< (point) (point-max))

      ;; orig buffer
      (set-buffer dotfile-buffer)
      (setq length (- 70 (current-column)))

      ;; help buffer
      (set-buffer help-buf)
      (setq fill-column length)
      (fill-region (point-min) (point-max))
      (goto-char (point-min))
      (end-of-line)
      (setq end (point))

      ;; orig buffer
      (set-buffer dotfile-buffer)
      (insert "\"")
      (insert-buffer-substring help-buf start end)
      (insert "\"")

      ;; help buffer
      (set-buffer help-buf)
      (if (< (+ 1 (point)) (point-max))
          (progn
            ;; orig buffer
            (set-buffer dotfile-buffer)
            (insert "\\\n")
            ))

      
      ;; orig buffer
      (set-buffer dotfile-buffer)
      (tcl-indent-command)
      
      ;;; help buffer
      (set-buffer help-buf)
      (delete-region start (+ 1 end)))

    ;; help-buf
    (set-buffer help-buf)
    (erase-buffer)
    (pop-to-buffer dotfile-buffer)
    ))

(global-set-key [f12] 'dotfile-create-help-buffer)
(global-set-key [S-f12] 'dotfile-help)
 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Local Variables:
;;; eval: (defun byte-compile-this-file () (write-region (point-min) (point-max) buffer-file-name nil 't) (byte-compile-file buffer-file-name) nil)
;;; write-file-hooks: (byte-compile-this-file)
;;; End:

