;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; ISPELL setup
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(fmakunbound 'ispell)                   ; Undefine the Emacs builtin 'ispell
(fmakunbound 'ispell-buffer)            ; Undefine the Emacs builtin 'ispell-buffer
(fmakunbound 'ispell-region)            ; Undefine the Emacs builtin 'ispell-region

(autoload 'ispell-word "ispell"
  "Check the spelling of word in buffer." t)
(global-set-key "\e$" 'ispell-word)
(autoload 'ispell-region "ispell"
  "Check the spelling of region." t)
(autoload 'ispell-buffer "ispell"
  "Check the spelling of buffer." t)
(autoload 'ispell-complete-word "ispell"
  "Look up current word in dictionary and try to complete it." t)
(autoload 'ispell-change-dictionary "ispell"
  "Change ispell dictionary." t)

;; ISPELL end.


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; REVERTING
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(autoload 'etn-revert-buffer "etn-revert-buffer" "Revert buffer" t)



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; term setup
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun term-setup-func ()
  (interactive)
  "Function to set up terminal"
  (if (eq window-system 'x)
      (progn

        (standard-display-european 1)
        (load "disp-table")
        (load "iso-syntax")
        (load "iso-insert")
        )
    (progn
      )
    ))

(if (eq window-system 'x)
    (progn 
      (setq term-setup-hook '(term-setup-func))
      )
  (progn
    (defun redefine-function-variables()
      (setq F3-func    'compile)
      (setq H-F3-func  'latex-buffer)
      (setq F5-func    'etn-revert-buffer)
      );; redefine

    (load "ifad-mode")
    (ifad-terminal-mode)
    ))	



  
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; My configurations 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; bining keys
(global-set-key (quote [C-f27]) (quote beginning-of-buffer))
(global-set-key (quote [C-f33]) (quote end-of-buffer))
(global-set-key (quote [f27]) (quote scroll-down))
(global-set-key (quote [f33]) (quote scroll-up))


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; IMADA taste bindinger
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(global-set-key [C-delete] 'undo)
(global-set-key [f1] 'help-for-help)
(global-set-key [f2] 'LaTeX-section)
(global-set-key [f3] 'goto-line)
(global-set-key [f4] 'dk-latin1-mode)
(global-set-key [f5] 'other-window)
(global-set-key [f6] 'undo)
;;;  (global-set-key [f7] 'save-all-buffers)
;;;  (global-set-key [f8] 'TeX-command-region)
(global-set-key [f9] 'compile)
(global-set-key [f21] 'ispell-word)
(global-set-key [f29] 'scroll-down)
(global-set-key [f35] 'scroll-up)
(global-set-key [kp-subtract] 'other-window-backwards)
(global-set-key [kp-add] 'other-window)

;;;; The [5]-keys

(defvar home-map (make-sparse-keymap))
(global-set-key [f31] home-map)       ;

(define-key home-map [f1] 'help-for-help)
(define-key home-map [f2] 'LaTeX-environment)
(define-key home-map [f3] 'move-to-buffer)
(define-key home-map [f4] 'dk-latin1-mode)
(define-key home-map [f5] 'other-window)
(define-key home-map [f6] 'undo)
(define-key home-map [f7] 'save-all-buffers)
(define-key home-map [f8] 'TeX-command-region)
(define-key home-map [f9] 'compile)
(define-key home-map [f21] 'ispell-region)
(define-key home-map [up]     'scroll-down) 
(define-key home-map [left]   'backward-word)
(define-key home-map [right]  'forward-word)
(define-key home-map [down]   'scroll-up) 
(define-key home-map [f27]    'beginning-of-other-window);; Home
(define-key home-map [f29]    'scroll-other-window-backwards)
(define-key home-map [f33]    'end-of-other-window);; End
(define-key home-map [f35]    'scroll-other-window)
(define-key home-map [kp-add] 'other-window-backwards);; Home
(define-key home-map [f4]     'dk-tex-mode)
(define-key home-map [insert] 'auto-fill-mode)

(define-key home-map "\["  'latex-danish-ae)
(define-key home-map "\\"  'latex-danish-oe)
(define-key home-map "\]"  'latex-danish-aa)
(define-key home-map "\{"  'latex-danish-AE)
(define-key home-map "\|"  'latex-danish-OE)
(define-key home-map "\}"  'latex-danish-AA)

;;;; [5]-[5]-keys

(defvar home-home-map (make-sparse-keymap))
(define-key home-map [f31] home-home-map) ;

(define-key home-home-map [f1] 'help-for-help)
(define-key home-home-map [f4] 'dk-latin1-mode)
(define-key home-home-map [f5] 'other-window)
(define-key home-home-map [f6] 'undo)
(define-key home-home-map [f7] 'save-all-buffers)
(define-key home-home-map [f8] 'TeX-command-region)
(define-key home-home-map [f9] 'compile)
(define-key home-home-map [f21] 'ispell-buffer)
(define-key home-home-map [up] 'beginning-of-buffer)
(define-key home-home-map [down] 'end-of-buffer)
(define-key home-home-map [left]   'beginning-of-line) 
(define-key home-home-map [right]  'end-of-line) 
(define-key home-home-map [f4] 'dk-plain-mode)
(global-set-key "" (quote search-forward-regexp))
(global-set-key "" (quote previous-error))
(global-set-key (quote [4194400]) (quote next-error))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(setq rcs-bind-keys nil)		; prevent rcs.el from binding any keys
(load "rcs")

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; AUC TeX 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(require 'tex-site)
(setq TeX-auto-local nil)
(setq-default TeX-master nil)
(setq LaTeX-version "2e")
(setq TeX-parse-self t)                 ; determine LaTeX/LaTeX2e


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Local Variables:
;;; eval: (defun byte-compile-this-file () (write-region (point-min) (point-max) buffer-file-name nil 't) (byte-compile-file buffer-file-name) nil)
;;; write-file-hooks: (byte-compile-this-file)
;;; End:
