;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; text-mode
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(setq text-mode-hook
      (function
       (lambda ()
	 "Set fill column and turn on auto-fill-mode"
	 (setq indent-line-function 'indent-relative-maybe)
	 (setq fill-column 72)
;	 (auto-fill-mode 1)
	 (local-set-key "\t" (quote self-insert-command))
	 (setq tab-width 2)
 ))) ;; text-mode-hook


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; html-helper-mode
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(autoload 'html-helper-mode "html-helper-mode" "Yay HTML" t)
(setq html-helper-do-write-file-hooks t)
;(setq html-helper-build-new-buffer t)
(setq html-helper-address-string 
  "<a href=\"http://www.imada.ou.dk/~blackie/\">Jesper Kj&aelig;r Pedersen</a> &lt;blackie@imada.ou.dk&gt;")


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; makefile-mode
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(add-hook 'makefile-mode-hook
          '(lambda () (setq indent-tabs-mode t))) ; Make tab insert as tab



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; tcl-mode
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(add-hook 'tcl-mode-hook
	  (function (lambda ()
		      (outline-minor-mode)
		      ;(hide-other)
          (setq tcl-indent-level 2)
          (setq tcl-continued-indent-level 2)
          (imenu-add-to-menubar "INDEX")
		      )))


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; python mode
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; python mode
(autoload 'python-mode "python-mode" "" t)

;;; let emacs know what the command line look like in python
(add-hook 'python-mode-hook
	  (function (lambda ()
                (outline-minor-mode)
                (setq py-indent-offset 2)
                (setq comint-prompt-regexp "^>>> "))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; latex-mode
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; adding outline mode to latex mode
(add-hook 'LaTeX-mode-hook
	  (function
     (lambda ()
       (progn
         (outline-minor-mode)
         (auto-fill-mode 1)
         (setq-default TeX-master nil)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; smart-recenter
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; When C-l is hit, the line with point in is placed alternating in the
;; bottom, middle and top of the window. 
(global-set-key "\C-l" 'smart-recenter)
(autoload 'smart-recenter
          "smart-recenter"
          "Recenter point at top, middle and bottom of window" t)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; hippie-expand
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; completions and expansions. 
(setq hippie-expand-verbose nil)          ; tell which try-function is used.
(autoload 'hippie-expand "hippie-expand" "Try to expand text." t)
(global-set-key "\M- " 'hippie-expand) 



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; lisp-interaction-mode
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; flgende stter alt-tab og return i lisp-interaction-mode
; som er den emacs starter op i.
(add-hook 'lisp-interaction-mode-hook
	  '(lambda () (progn (local-set-key "\t" 'lisp-complete-symbol))))


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; emacs-lisp-mode-hook
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; flgende stter alt-tab og return i lisp-interaction-mode
; som er den emacs starter op i.
(add-hook 'emacs-lisp-mode-hook
	  '(lambda () (progn (local-set-key [M-tab] 'lisp-complete-symbol))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; dired-load-hook
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(setq dired-load-hook
      (function
       (lambda ()
         "Tilfoejer 'Q' som kill-ftp buffer til Dired"
         (define-key dired-mode-map "Q" 'ange-ftp-kill-ftp-process)
         )))



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; vdmde-19
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; configure vdmde
;(load-library "vdmde-19")
;(setq vdmde-mode-hook
;      (function
;       (lambda ()
;         (setq comint-prompt-regexp "^vdm> ")
;         (global-set-key "" (quote comint-bol))
;         (global-set-key "" 'comint-next-matching-input-from-input)
;         (global-set-key "" 'comint-previous-matching-input-from-input)
;         )))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Hilit19
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(cond (window-system
       (setq hilit-mode-enable-list '(not text-mode)
             hilit-inhibit-hooks    t                ; not INFO
             hilit-quietly          t                ; do tell me what you do
             hilit-face-check       nil)             ; dont check faces
       (if (x-display-color-p)
           (setq  hilit-background-mode  'light)
         (setq hilit-background-mode 'mono))
       (require 'hilit19)
       (global-set-key "\C-m" 'hilit19-newline-function)
       (global-set-key "\t" 'hilit19-tab-function)
       (global-set-key " " 'hilit19-space)
       (add-hook 'html-helper-load-hook
                 (function (lambda ()
                             (define-key html-helper-mode-map
                               "\C-m" 'hilit19-newline-function)
                             (define-key html-helper-mode-map
                               "\t" 'hilit19-html-tab-function))))
       ))


(defun hilit19-newline-function ()
  (interactive)
  (newline-and-indent)
  (hilit-repaint-command '-))

(defun hilit19-tab-function ()
  (interactive)
  (indent-for-tab-command)
  (hilit-repaint-command '-))

(defun hilit19-html-tab-function ()
  (interactive)
  (html-helper-indent-command)
  (hilit-repaint-command '-))

(defun hilit19-space ()
  (interactive)
  (self-insert-command 1)
  (hilit-repaint-command '-))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; eldoc - describe functions on the fly
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(autoload 'turn-on-eldoc-mode "eldoc" nil t)
(add-hook 'emacs-lisp-mode-hook 'turn-on-eldoc-mode)
(add-hook 'lisp-interaction-mode-hook 'turn-on-eldoc-mode)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; pathsearch - search for C include fiel
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(if (eq setup-location 'HOME)
    (setq pathsearch-c-include-path '("/usr/local/include"
        "/usr/local/i586-unknown-linux/include"
        "/usr/local/lib/gcc-lib/i586-unknown-linux/2.7.2/include"
        "/usr/include")))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; imenu, pyimenu
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(autoload 'imenu-add-to-menubar "imenu" nil t)
(autoload 'imenu-example--create-python-index "pyimenu")
(add-hook 'emacs-lisp-mode-hook
          (function (lambda () (imenu-add-to-menubar "INDEX"))))
(add-hook 'lisp-interaction-mode-hook
          (function (lambda () (imenu-add-to-menubar "INDEX"))))
(add-hook 'c-mode-hook
          (function (lambda ()  (imenu-add-to-menubar "INDEX"))))
(add-hook 'c++-mode-hook
          (function (lambda ()  (imenu-add-to-menubar "INDEX"))))
(add-hook 'python-mode-hook
          (function
           (lambda ()
             (setq imenu-create-index-function
                   (function imenu-example--create-python-index))
             (imenu-add-to-menubar "INDEX"))))
(setq imenu-max-items 40)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; electric help
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(require 'ehelp)
(define-key global-map "\C-h" 'ehelp-command)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Local Variables:
;;; eval: (defun byte-compile-this-file () (write-region (point-min) (point-max) buffer-file-name nil 't) (byte-compile-file buffer-file-name) nil)
;;; write-file-hooks: (byte-compile-this-file)
;;; End:
